ig.module( 
	'game.entities.friend' 
)
.requires(
	'impact.entity'
)
.defines(function(){

	EntityFriend = ig.Entity.extend({

		size : {
			x : 33,
			y : 36
		}, 
			
		animSheet : new ig.AnimationSheet( 'media/chars_more.png', 32, 48 ),

		collides: ig.Entity.COLLIDES.FIXED,
    	type: ig.Entity.TYPE.B,
    	// checkAgainst: ig.Entity.TYPE.B,

    	//own keys
    	movePossibilities : new Array('moveDown','moveLeft','moveRight','moveUp'),
    	moveUpdateTime : 6,
    	moveOnce : false,
    	speed : 60,
		stopOnce : true,

		init: function( x, y, settings ) {
			var animSpeed = 0.1;
			var animStop = false;
			this.addAnim('idleDown', 1, [51]);
			this.addAnim('idleRight', 1, [75]);
			this.addAnim('idleLeft', 1, [63]);
			this.addAnim('idleUp', 1, [87]);

			this.addAnim( 'moveDown', animSpeed, [51, 52, 53], animStop);
			this.addAnim( 'moveLeft', animSpeed, [63, 64, 65], animStop);
			this.addAnim( 'moveRight', animSpeed, [75, 76, 77], animStop);
			this.addAnim( 'moveUp', animSpeed, [87, 88, 89], animStop);

			this.timer = new ig.Timer();

			this.parent(x,y,settings);
		},

		update: function() {
			
			this.move();
			this.currentAnim.update();

			this.parent();
		}, 

		move: function() {

			var changeDirectionInfluencer = parseInt(this.timer.delta()) % this.moveUpdateTime;
			var index = parseInt(Math.random() * 100) % this.movePossibilities.length;

			if(changeDirectionInfluencer === 0 && this.moveOnce) {
				this.moveOnce = false;
				if(this.movePossibilities[index] === 'moveRight') {
					this.moveRight();
				}else if(this.movePossibilities[index] === 'moveLeft'){
					this.moveLeft();
				}else if(this.movePossibilities[index] === 'moveUp'){
					this.moveUp();
				}else if(this.movePossibilities[index] === 'moveDown'){
					this.moveDown();
				}
			}else if(changeDirectionInfluencer === 1){
				this.moveOnce = true;
				if(this.stopOnce) {
					this.moveStop(this.movePossibilities[index]);
					this.stopOnce = false;
				}
			}else if(changeDirectionInfluencer === 2) {
				this.stopOnce = true;
			}
		},

		moveRight: function() {
			this.currentAnim = this.anims.moveRight;
			this.vel.x = this.speed;
		},

		moveLeft: function() {
			this.currentAnim = this.anims.moveLeft;
			this.vel.x = -this.speed;
		},

		moveDown: function() {
			this.currentAnim = this.anims.moveDown;
			this.vel.y = this.speed;
		},

		moveUp: function() {
			this.currentAnim = this.anims.moveUp;
			this.vel.y = -this.speed;
		},

		moveStop: function(oldState) {
			this.vel.y = 0;
			this.vel.x = 0;
			if(oldState === this.movePossibilities[2]){
				// right
				this.currentAnim = this.anims.idleRight;
			}else if(oldState === this.movePossibilities[1]){
				//left
				this.currentAnim = this.anims.idleLeft;
			}else if(oldState === this.movePossibilities[0]){
				//down
				this.currentAnim = this.anims.idleDown;
			}else if(oldState === this.movePossibilities[3]){
				//up
				this.currentAnim = this.anims.idleUp;
			}
		}
	});

});